@@ -240,6 +240,8 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 	if (!account) {
 		GtkTreeView  *view;
 		GtkTreeModel *model;
+		GString      *string;
+		gchar        *str;
 
 		gtk_widget_show (dialog->frame_no_account);
 		gtk_widget_hide (dialog->vbox_details);
@@ -250,25 +252,32 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 		view = GTK_TREE_VIEW (dialog->treeview);
 		model = gtk_tree_view_get_model (view);
 
+		if (empathy_profile_chooser_n_profiles (dialog->combobox_profile) > 0) {
+			string = g_string_new (_("To add a new account, you can click on the "
+						 "'Add' button and a new entry will be created "
+						 "for you to start configuring."));
+		} else {
+			string = g_string_new (_("To add a new account, you first have to "
+						 "install a backend for each protocol "
+						 "you want to use."));
+		}
+
 		if (gtk_tree_model_iter_n_children (model, NULL) > 0) {
 			gtk_label_set_markup (GTK_LABEL (dialog->label_no_account),
 					      _("<b>No Account Selected</b>"));
-			gtk_label_set_markup (GTK_LABEL (dialog->label_no_account_blurb),
-					      _("To add a new account, you can click on the "
-						"'Add' button and a new entry will be created "
-						"for you to start configuring.\n"
-						"\n"
-						"If you do not want to add an account, simply "
-						"click on the account you want to configure in "
-						"the list on the left."));
+			g_string_append (string, _("\n\n"
+					"If you do not want to add an account, simply "
+					"click on the account you want to configure in "
+					"the list on the left."));
 		} else {
 			gtk_label_set_markup (GTK_LABEL (dialog->label_no_account),
 					      _("<b>No Accounts Configured</b>"));
-			gtk_label_set_markup (GTK_LABEL (dialog->label_no_account_blurb),
-					      _("To add a new account, you can click on the "
-						"'Add' button and a new entry will be created "
-						"for you to start configuring."));
 		}
+
+		str = g_string_free (string, FALSE);
+		gtk_label_set_markup (GTK_LABEL (dialog->label_no_account_blurb),
+				      str);
+		g_free (str);
 	} else {
 		McProfile *profile;
 		const gchar *config_ui;
@@ -313,10 +322,8 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 		gtk_image_set_from_icon_name (GTK_IMAGE (dialog->image_type),
 					      mc_profile_get_icon_name (profile),
 					      GTK_ICON_SIZE_DIALOG);
-		/* FIXME: Uncomment once we depend on GTK+ 2.12
 		gtk_widget_set_tooltip_text (dialog->image_type,
 					     mc_profile_get_display_name (profile));
-		*/
 
 		text = g_strdup_printf ("<big><b>%s</b></big>", mc_account_get_display_name (account));
 		gtk_label_set_markup (GTK_LABEL (dialog->label_name), text);
@@ -748,28 +755,18 @@ accounts_dialog_status_changed_cb (MissionControl                  *mc,
 			break;
 		}
 	}
-
 	g_object_unref (account);
 
-	/* Start to flash account if status is connecting */
-	if (status == TP_CONN_STATUS_CONNECTING) {
-		if (!dialog->connecting_id) {
-			dialog->connecting_id = g_timeout_add (FLASH_TIMEOUT,
-							       (GSourceFunc) accounts_dialog_flash_connecting_cb,
-							       dialog);
-		}
-
-		return;
-	}
-
-	/* Stop to flash if no account is connecting */
+	/* Check if there is still accounts in CONNECTING state */
 	accounts = mc_accounts_list ();
 	for (l = accounts; l; l = l->next) {
-		McAccount *this_account;
+		McAccount                 *this_account;
+		TelepathyConnectionStatus  status;
 
 		this_account = l->data;
 
-		if (mission_control_get_connection_status (mc, this_account, NULL) == TP_CONN_STATUS_CONNECTING) {
+		status = mission_control_get_connection_status (mc, this_account, NULL);
+		if (status == TP_CONN_STATUS_CONNECTING) {
 			found = TRUE;
 			break;
 		}
@@ -782,8 +779,11 @@ accounts_dialog_status_changed_cb (MissionControl                  *mc,
 		g_source_remove (dialog->connecting_id);
 		dialog->connecting_id = 0;
 	}
-
-	gtk_widget_show (dialog->window);
+	if (found && !dialog->connecting_id) {
+		dialog->connecting_id = g_timeout_add (FLASH_TIMEOUT,
+						       (GSourceFunc) accounts_dialog_flash_connecting_cb,
+						       dialog);
+	}
 }
 
 static void
@@ -953,6 +953,9 @@ accounts_dialog_destroy_cb (GtkWidget            *widget,
 	g_signal_handlers_disconnect_by_func (dialog->monitor,
 					      accounts_dialog_account_removed_cb,
 					      dialog);
+	g_signal_handlers_disconnect_by_func (dialog->monitor,
+					      accounts_dialog_update_connect_button,
+					      dialog);
 	dbus_g_proxy_disconnect_signal (DBUS_G_PROXY (dialog->mc),
 					"AccountStatusChanged",
 					G_CALLBACK (accounts_dialog_status_changed_cb),
@@ -1044,18 +1047,26 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 			  dialog->combobox_profile,
 			  TRUE, TRUE, 0);
 	gtk_widget_show (dialog->combobox_profile);
+	if (empathy_profile_chooser_n_profiles (dialog->combobox_profile) <= 0) {
+		gtk_widget_set_sensitive (dialog->button_add, FALSE);
+	}
 
 	/* Set up signalling */
 	dialog->mc = empathy_mission_control_new ();
 	dialog->monitor = mc_account_monitor_new ();
 
-	/* FIXME: connect account-enabled/disabled too */
 	g_signal_connect (dialog->monitor, "account-created",
 			  G_CALLBACK (accounts_dialog_account_added_cb),
 			  dialog);
 	g_signal_connect (dialog->monitor, "account-deleted",
 			  G_CALLBACK (accounts_dialog_account_removed_cb),
 			  dialog);
+	g_signal_connect_swapped (dialog->monitor, "account-enabled",
+				  G_CALLBACK (accounts_dialog_update_connect_button),
+				  dialog);
+	g_signal_connect_swapped (dialog->monitor, "account-disabled",
+				  G_CALLBACK (accounts_dialog_update_connect_button),
+				  dialog);
 	dbus_g_proxy_connect_signal (DBUS_G_PROXY (dialog->mc), "AccountStatusChanged",
 				     G_CALLBACK (accounts_dialog_status_changed_cb),
 				     dialog, NULL);
