@@ -2,20 +2,19 @@
 /*
  * Copyright (C) 2007 Collabora Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
@@ -29,8 +28,11 @@
 #include <glade/glade.h>
 #include <glib/gi18n.h>
 
+#include <libmissioncontrol/mission-control.h>
+
 #include <libempathy/empathy-contact-manager.h>
 #include <libempathy/empathy-contact-list.h>
+#include <libempathy/empathy-utils.h>
 
 #include "empathy-contact-dialogs.h"
 #include "empathy-contact-widget.h"
@@ -110,7 +112,8 @@ empathy_subscription_dialog_show (EmpathyContact *contact,
 				      NULL);
 
 	contact_widget = empathy_contact_widget_new (contact,
-						     CONTACT_WIDGET_TYPE_SUBSCRIPTION);
+						     EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
+						     EMPATHY_CONTACT_WIDGET_EDIT_GROUPS);
 	gtk_box_pack_end (GTK_BOX (hbox_subscription),
 			  contact_widget,
 			  TRUE, TRUE,
@@ -146,13 +149,14 @@ contact_information_response_cb (GtkDialog *dialog,
 void
 empathy_contact_information_dialog_show (EmpathyContact *contact,
 					 GtkWindow      *parent,
-					 gboolean        edit)
+					 gboolean        edit,
+					 gboolean        is_user)
 {
 	GtkWidget                *dialog;
 	GtkWidget                *button;
 	GtkWidget                *contact_widget;
 	GList                    *l;
-	EmpathyContactWidgetType  type;
+	EmpathyContactWidgetFlags flags = 0;
 
 	g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
@@ -164,13 +168,19 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
 		return;
 	}
 
-	type = edit ? CONTACT_WIDGET_TYPE_EDIT : CONTACT_WIDGET_TYPE_SHOW;
-
 	/* Create dialog */
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Contact information"));
+	if (is_user) {
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Personal Information"));
+	}
+	else if (edit) {
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Edit Contact Information"));
+	}
+	else {
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Contact Information"));
+	}
 
 	/* Close button */
 	button = gtk_button_new_with_label (GTK_STOCK_CLOSE);
@@ -179,12 +189,27 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
 				      button,
 				      GTK_RESPONSE_CLOSE);
 	gtk_widget_show (button);
-	
+
 	/* Contact info widget */
-	contact_widget = empathy_contact_widget_new (contact, type);
+	if (edit) {
+		flags |= EMPATHY_CONTACT_WIDGET_EDIT_ALIAS;
+	}
+	if (is_user) {
+		flags |= EMPATHY_CONTACT_WIDGET_EDIT_ACCOUNT;
+		flags |= EMPATHY_CONTACT_WIDGET_EDIT_AVATAR;
+	}
+	if (!is_user && edit) {
+		flags |= EMPATHY_CONTACT_WIDGET_EDIT_GROUPS;
+	}
+	contact_widget = empathy_contact_widget_new (contact, flags);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 			    contact_widget,
 			    TRUE, TRUE, 0);
+	if (flags & EMPATHY_CONTACT_WIDGET_EDIT_ACCOUNT) {
+		empathy_contact_widget_set_account_filter (contact_widget,
+							   empathy_account_chooser_filter_is_connected,
+							   NULL);
+	}
 
 	g_object_set_data (G_OBJECT (dialog), "contact_widget", contact_widget);
 	information_dialogs = g_list_prepend (information_dialogs, dialog);
@@ -204,6 +229,37 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
  *  New contact dialog
  */
 
+static gboolean
+can_add_contact_to_account (McAccount *account,
+			    gpointer   user_data)
+{
+	MissionControl            *mc;
+	TelepathyConnectionStatus  status;
+	McProfile                 *profile;
+	const gchar               *protocol_name;
+
+	mc = empathy_mission_control_new ();
+	status = mission_control_get_connection_status (mc, account, NULL);
+	g_object_unref (mc);
+	if (status != TP_CONN_STATUS_CONNECTED) {
+		/* Account is disconnected */
+		return FALSE;
+	}
+
+	profile = mc_account_get_profile (account);
+	protocol_name = mc_profile_get_protocol_name (profile);
+	if (strcmp (protocol_name, "local-xmpp") == 0) {
+		/* We can't add accounts to a XMPP LL connection
+		 * FIXME: We should inspect the flags of the contact list group interface
+		 */
+		g_object_unref (profile);
+		return FALSE;
+	}
+
+	g_object_unref (profile);
+	return TRUE;
+}
+
 static void
 new_contact_response_cb (GtkDialog *dialog,
 			 gint       response,
@@ -242,7 +298,7 @@ empathy_new_contact_dialog_show (GtkWindow *parent)
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("New contact"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("New Contact"));
 
 	/* Cancel button */
 	button = gtk_button_new_with_label (GTK_STOCK_CANCEL);
@@ -261,10 +317,17 @@ empathy_new_contact_dialog_show (GtkWindow *parent)
 	gtk_widget_show (button);
 
 	/* Contact info widget */
-	contact_widget = empathy_contact_widget_new (NULL, CONTACT_WIDGET_TYPE_ADD);
+	contact_widget = empathy_contact_widget_new (NULL,
+						     EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
+						     EMPATHY_CONTACT_WIDGET_EDIT_ACCOUNT |
+						     EMPATHY_CONTACT_WIDGET_EDIT_ID |
+						     EMPATHY_CONTACT_WIDGET_EDIT_GROUPS);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 			    contact_widget,
 			    TRUE, TRUE, 0);
+	empathy_contact_widget_set_account_filter (contact_widget,
+						   can_add_contact_to_account,
+						   NULL);
 
 	new_contact_dialog = dialog;
 
